/*
 * demo44.c
 * 
 * Test to see the effect of the different return types.
 * 
 */

#include <stdlib.h>
#include <stdio.h>
#include "forms.h"

FL_FORM *form;

FL_OBJECT
        *outputobj,
        *sliderobj,
        *dialobj,
        *positionerobj,
        *counterobj,
        *inputobj;
 
/*** Call-Back Routines ***/

void set_return(FL_OBJECT *obj,  long arg)
{
    fl_set_slider_return(sliderobj, (int) arg);
    fl_set_dial_return(dialobj, (int) arg);
    fl_set_positioner_return(positionerobj, (int) arg);
    fl_set_counter_return(counterobj, (int) arg);
    fl_set_input_return(inputobj, (int) arg);
}

void quit_cb(FL_OBJECT *obj, long arg)
{
    exit(0);
}

void action_cb(FL_OBJECT *obj, long arg)
{
    char str[256];
    switch (arg) {
	case 0: /* Slider */
	    sprintf(str, "Slider: %5.3f", fl_get_slider_value(obj)); break;
	case 1: /* Dial */
	    sprintf(str, "Dial: %5.3f", fl_get_dial_value(obj)); break;
	case 2: /* Position */
	    sprintf(str, "Position: (%5.3f, %5.3f)", 
			fl_get_positioner_xvalue(obj), fl_get_positioner_yvalue(obj)); break;
	case 3: /* Counter */
	    sprintf(str, "Counter: %5.3f", fl_get_counter_value(obj)); break;
	case 4: /* Input */
	    sprintf(str, "Input: %s", fl_get_input(obj)); break;
    }
    fl_addto_browser(outputobj, str);
}

/**** Creating the Form ****/

void create_form_form(void)
{
  FL_OBJECT *obj;
  form = fl_bgn_form(FL_NO_BOX,600.0,420.0);
  obj = fl_add_box(FL_UP_BOX,0.0,0.0,600.0,420.0,"");
  obj = fl_add_box(FL_FRAME_BOX,10.0,220.0,280.0,140.0,"Setting");
    fl_set_object_align(obj,FL_ALIGN_BOTTOM);
  obj = fl_add_box(FL_SHADOW_BOX,80.0,370.0,420.0,40.0,"Different Return Types");
    fl_set_object_color(obj,9,47);
    fl_set_object_lsize(obj,20.000000);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_lightbutton(FL_RADIO_BUTTON,20.0,320.0,260.0,30.0,"FL_RETURN_END_CHANGED");
    fl_set_call_back(obj,set_return,0);
  obj = fl_add_lightbutton(FL_RADIO_BUTTON,20.0,290.0,260.0,30.0,"FL_RETURN_CONT_CHANGED");
    fl_set_call_back(obj,set_return,1);
  obj = fl_add_lightbutton(FL_RADIO_BUTTON,20.0,260.0,260.0,30.0,"FL_RETURN_END_ALWAYS");
    fl_set_call_back(obj,set_return,2);
  obj = fl_add_lightbutton(FL_RADIO_BUTTON,20.0,230.0,260.0,30.0,"FL_RETURN_CONT_ALWAYS");
    fl_set_call_back(obj,set_return,3);
  outputobj = obj = fl_add_browser(FL_NORMAL_BROWSER,10.0,30.0,280.0,160.0,"Result");
    fl_set_object_boxtype(obj,FL_FRAME_BOX);
  obj = fl_add_box(FL_FRAME_BOX,300.0,140.0,290.0,220.0,"Object");
    fl_set_object_align(obj,FL_ALIGN_BOTTOM);
  obj = fl_add_button(FL_NORMAL_BUTTON,490.0,20.0,90.0,30.0,"Quit");
    fl_set_call_back(obj,quit_cb,0);
  sliderobj = obj = fl_add_slider(FL_VERT_SLIDER,310.0,150.0,50.0,200.0,"");
    fl_set_call_back(obj,action_cb,0);
  dialobj = obj = fl_add_dial(FL_NORMAL_DIAL,370.0,250.0,100.0,100.0,"");
    fl_set_call_back(obj,action_cb,1);
  positionerobj = obj = fl_add_positioner(FL_NORMAL_POSITIONER,480.0,250.0,100.0,100.0,"");
    fl_set_call_back(obj,action_cb,2);
  counterobj = obj = fl_add_counter(FL_NORMAL_COUNTER,370.0,200.0,210.0,30.0,"");
    fl_set_call_back(obj,action_cb,3);
  inputobj = obj = fl_add_input(FL_NORMAL_INPUT,370.0,150.0,210.0,30.0,"");
    fl_set_call_back(obj,action_cb,4);
  fl_end_form();
}

/*---------------------------------------*/

void create_the_forms(void)
{
  create_form_form();
}


/**** Main Program ****/

main()
{
    create_the_forms();
    fl_show_form(form, FL_PLACE_CENTER, FALSE, NULL);
    fl_do_forms();
}
